@@ -6,6 +6,7 @@ namespace Icinga\Application;
 use DirectoryIterator;
 use ErrorException;
 use Exception;
+use Icinga\Application\ProvidedHook\DbMigration;
 use ipl\I18n\GettextTranslator;
 use ipl\I18n\StaticTranslator;
 use LogicException;
@@ -43,7 +44,7 @@ abstract class ApplicationBootstrap
     /**
      * Base directory
      *
-     * Parent folder for at least application, bin, modules, library/vendor and public
+     * Parent folder for at least application, bin, modules and public
      *
      * @var string
      */
@@ -56,13 +57,6 @@ abstract class ApplicationBootstrap
      */
     protected $appDir;
 
-    /**
-     * Vendor library directory
-     *
-     * @var string
-     */
-    protected $vendorDir;
-
     /**
      * Icinga library directory
      *
@@ -161,7 +155,6 @@ abstract class ApplicationBootstrap
         }
         $this->baseDir = $baseDir;
         $this->appDir = $baseDir . '/application';
-        $this->vendorDir = $baseDir . '/library/vendor';
         if (substr(__DIR__, 0, 8) === 'phar:///') {
             $this->libDir = dirname(dirname(__DIR__));
         } else {
@@ -206,15 +199,6 @@ abstract class ApplicationBootstrap
             }
         }
 
-        set_include_path(
-            implode(
-                PATH_SEPARATOR,
-                array($this->vendorDir, get_include_path())
-            )
-        );
-
-        Benchmark::measure('Bootstrap, autoloader registered');
-
         Icinga::setApp($this);
 
         require_once dirname(__FILE__) . '/functions.php';
@@ -328,18 +312,6 @@ abstract class ApplicationBootstrap
         return $this->getDirWithSubDir($this->appDir, $subDir);
     }
 
-    /**
-     * Get the vendor library directory
-     *
-     * @param   string $subDir Optional sub directory to get
-     *
-     * @return  string
-     */
-    public function getVendorDir($subDir = null)
-    {
-        return $this->getDirWithSubDir($this->vendorDir, $subDir);
-    }
-
     /**
      * Get the configuration directory
      *
@@ -452,10 +424,15 @@ abstract class ApplicationBootstrap
 
     protected function getAvailableModulePaths()
     {
-        $paths = array();
-        $configured = $this->config->get('global', 'module_path', $this->baseDir . '/modules');
+        $paths = [];
+
+        $configured = getenv('ICINGAWEB_MODULES_DIR');
+        if (! $configured) {
+            $configured = $this->config->get('global', 'module_path', $this->baseDir . '/modules');
+        }
+
         $nextIsPhar = false;
-        foreach (explode(':', $configured) as $path) {
+        foreach (explode(PATH_SEPARATOR, $configured) as $path) {
             if ($path === 'phar') {
                 $nextIsPhar = true;
                 continue;
@@ -672,7 +649,7 @@ abstract class ApplicationBootstrap
      */
     final protected function setupTimezone()
     {
-        $timezone = $this->detectTimeZone();
+        $timezone = $this->detectTimezone();
         if ($timezone === null || @date_default_timezone_set($timezone) === false) {
             date_default_timezone_set(@date_default_timezone_get());
         }
@@ -755,4 +732,16 @@ abstract class ApplicationBootstrap
         $localedir = $this->getLocaleDir();
         return $localedir !== false && file_exists($localedir) && is_dir($localedir);
     }
+
+    /**
+     * Register all hooks provided by the main application
+     *
+     * @return $this
+     */
+    protected function registerApplicationHooks(): self
+    {
+        Hook::register('DbMigration', DbMigration::class, DbMigration::class);
+
+        return $this;
+    }
 }
