@@ -40,14 +40,15 @@ class DateFormatter
      * Get the diff between the given time and the current time
      *
      * @param   int|float $time
+     * @param   bool      $requireTime
      *
      * @return  array
      */
-    protected static function diff($time)
+    protected static function diff($time, $requireTime = false)
     {
         $invert = false;
         $now = time();
-        $time = (float) $time;
+        $time = (int) $time;
         $diff = $time - $now;
         if ($diff < 0) {
             $diff = abs($diff);
@@ -56,9 +57,9 @@ class DateFormatter
         if ($diff > 3600 * 24 * 3) {
             $type = static::DATE;
             if (date('Y') === date('Y', $time)) {
-                $formatted = date('M j', $time);
+                $formatted = date($requireTime ? 'M j H:i' : 'M j', $time);
             } else {
-                $formatted = date('Y-m', $time);
+                $formatted = date($requireTime ? 'Y-m-d H:i' : 'Y-m', $time);
             }
         } else {
             $minutes = floor($diff / 60);
@@ -93,7 +94,7 @@ class DateFormatter
      */
     public static function formatDate($date)
     {
-        return date('Y-m-d', (float) $date);
+        return date('Y-m-d', (int) $date);
     }
 
     /**
@@ -105,7 +106,7 @@ class DateFormatter
      */
     public static function formatDateTime($dateTime)
     {
-        return date('Y-m-d H:i:s', (float) $dateTime);
+        return date('Y-m-d H:i:s', (int) $dateTime);
     }
 
     /**
@@ -140,7 +141,7 @@ class DateFormatter
      */
     public static function formatTime($time)
     {
-        return date('H:i:s', (float) $time);
+        return date('H:i:s', (int) $time);
     }
 
     /**
@@ -148,15 +149,18 @@ class DateFormatter
      *
      * @param   int|float   $time
      * @param   bool        $timeOnly
+     * @param   bool        $requireTime
      *
-     * @return  string
+     * @return  ?string
      */
-    public static function timeAgo($time, $timeOnly = false)
+    public static function timeAgo($time, $timeOnly = false, $requireTime = false)
     {
-        list($type, $ago, $invert) = static::diff($time);
+        list($type, $ago, $invert) = static::diff($time, $requireTime);
         if ($timeOnly) {
             return $ago;
         }
+
+        $formatted = null;
         switch ($type) {
             case static::DATE:
                 // Move to next case
@@ -184,15 +188,18 @@ class DateFormatter
      *
      * @param   int|float   $time
      * @param   bool        $timeOnly
+     * @param   bool        $requireTime
      *
-     * @return  string
+     * @return  ?string
      */
-    public static function timeSince($time, $timeOnly = false)
+    public static function timeSince($time, $timeOnly = false, $requireTime = false)
     {
-        list($type, $since, $invert) = static::diff($time);
+        list($type, $since, $invert) = static::diff($time, $requireTime);
         if ($timeOnly) {
             return $since;
         }
+
+        $formatted = null;
         switch ($type) {
             case static::RELATIVE:
                 $formatted = sprintf(
@@ -219,18 +226,21 @@ class DateFormatter
      *
      * @param   int|float   $time
      * @param   bool        $timeOnly
+     * @param   bool        $requireTime
      *
-     * @return  string
+     * @return  ?string
      */
-    public static function timeUntil($time, $timeOnly = false)
+    public static function timeUntil($time, $timeOnly = false, $requireTime = false)
     {
-        list($type, $until, $invert) = static::diff($time);
+        list($type, $until, $invert) = static::diff($time, $requireTime);
         if ($invert && $type === static::RELATIVE) {
             $until = '-' . $until;
         }
         if ($timeOnly) {
             return $until;
         }
+
+        $formatted = null;
         switch ($type) {
             case static::DATE:
                 // Move to next case
