@@ -6,8 +6,8 @@ namespace Icinga\Protocol\Ldap;
 use Icinga\Data\ConfigObject;
 use Icinga\Protocol\Dns;
 
-class Discovery {
-
+class Discovery
+{
     /**
      * @var LdapConnection
      */
@@ -46,12 +46,14 @@ class Discovery {
     {
         if ($this->isAd()) {
             return array(
+                'backend' => 'msldap',
                 'base_dn' => $this->connection->getCapabilities()->getDefaultNamingContext(),
                 'user_class' => 'user',
                 'user_name_attribute' => 'sAMAccountName'
             );
         } else {
             return array(
+                'backend' => 'ldap',
                 'base_dn' => $this->connection->getCapabilities()->getDefaultNamingContext(),
                 'user_class' => 'inetOrgPerson',
                 'user_name_attribute' => 'uid'
@@ -79,10 +81,20 @@ class Discovery {
         return $this->connection->discoverySuccessful();
     }
 
+    /**
+     * Why the discovery failed
+     *
+     * @return \Exception|null
+     */
+    public function getError()
+    {
+        return $this->connection->getDiscoveryError();
+    }
+
     /**
      * Discover LDAP servers on the given domain
      *
-     * @param  string   $domain The object containing the form elements
+     * @param  ?string   $domain The object containing the form elements
      *
      * @return Discovery        True when the discovery was successful, false when the configuration was guessed
      */
@@ -118,7 +130,7 @@ class Discovery {
      * @param $host         The host on which to execute the discovery
      * @param $port         The port on which to execute the discovery
      *
-     * @return Discover     The resulting Discovery
+     * @return Discovery     The resulting Discovery
      */
     public static function discover($host, $port)
     {
