@@ -28,7 +28,9 @@ class ProcessCheckResultCommandForm extends ObjectsCommandForm
     public function getSubmitLabel()
     {
         return $this->translatePlural(
-            'Submit Passive Check Result', 'Submit Passive Check Results', count($this->objects)
+            'Submit Passive Check Result',
+            'Submit Passive Check Results',
+            count($this->objects)
         );
     }
 
@@ -38,6 +40,7 @@ class ProcessCheckResultCommandForm extends ObjectsCommandForm
      */
     public function createElements(array $formData)
     {
+        $object = null;
         foreach ($this->getObjects() as $object) {
             /** @var \Icinga\Module\Monitoring\Object\MonitoredObject $object */
             // Nasty, but as getObjects() returns everything but an object with a real
@@ -91,6 +94,10 @@ class ProcessCheckResultCommandForm extends ObjectsCommandForm
     {
         foreach ($this->objects as $object) {
             /** @var \Icinga\Module\Monitoring\Object\MonitoredObject $object */
+            if (! $object->passive_checks_enabled) {
+                continue;
+            }
+
             $command = new ProcessCheckResultCommand();
             $command->setObject($object);
             $command->setStatus($this->getValue('status'));
