@@ -89,6 +89,11 @@
                 $target = this.getLinkTargetFor($form);
             }
 
+            // Overwrite the URL only if the form is not auto submitted
+            if (! $autoSubmittedBy && $button.hasAttr('formaction')) {
+                url = $button.attr('formaction');
+            }
+
             if (! url) {
                 // Use the URL of the target container if the form's action is not set
                 url = $target.closest('.container').data('icinga-url');
@@ -184,9 +189,24 @@
                 }
             }
 
-            var extraHeaders = {};
-            if ($autoSubmittedBy && ($autoSubmittedBy.attr('name') || $autoSubmittedBy.attr('id'))) {
-                extraHeaders['X-Icinga-AutoSubmittedBy'] = $autoSubmittedBy.attr('name') || $autoSubmittedBy.attr('id');
+            let extraHeaders = {};
+            if ($autoSubmittedBy) {
+                let id;
+                if (($autoSubmittedBy.attr('name') || $autoSubmittedBy.attr('id'))) {
+                    id = $autoSubmittedBy.attr('name') || $autoSubmittedBy.attr('id');
+                } else {
+                    let formSelector = icinga.utils.getCSSPath($form);
+                    let nearestKnownParent = $autoSubmittedBy.closest(
+                        formSelector + ' [name],' + formSelector + ' [id]'
+                    );
+                    if (nearestKnownParent) {
+                        id = nearestKnownParent.attr('name') || nearestKnownParent.attr('id');
+                    }
+                }
+
+                if (id) {
+                    extraHeaders['X-Icinga-AutoSubmittedBy'] = id;
+                }
             }
 
             var req = this.loadUrl(url, $target, data, method, undefined, undefined, undefined, extraHeaders);
@@ -196,8 +216,9 @@
             req.progressTimer = progressTimer;
 
             if ($autoSubmittedBy) {
-                if ($autoSubmittedBy.closest('.controls').length) {
-                    $('.content', req.$target).addClass('impact');
+                const $closestControls = $autoSubmittedBy.closest('.controls');
+                if ($closestControls.length && $closestControls[0].parentNode === req.$target[0]) {
+                    $(':scope > .content', req.$target).addClass('impact');
                 } else {
                     req.$target.addClass('impact');
                 }
@@ -278,6 +299,11 @@
                 headers['X-Icinga-Autorefresh'] = '1';
             }
 
+            if ($target.is('#col2')) {
+                headers['X-Icinga-Col1-State'] = this.icinga.history.getCol1State();
+                headers['X-Icinga-Col2-State'] = this.icinga.history.getCol2State().replace(/^#!/, '');
+            }
+
             // Ask for a new window id in case we don't already have one
             if (this.icinga.ui.hasWindowId()) {
                 var windowId = this.icinga.ui.getWindowId();
@@ -471,6 +497,7 @@
          */
         processRedirectHeader: function(req) {
             var icinga      = this.icinga,
+                $redirectTarget  = req.$redirectTarget,
                 redirect    = req.getResponseHeader('X-Icinga-Redirect');
 
             if (! redirect) {
@@ -502,11 +529,11 @@
                 var originUrl = req.$target.data('icingaUrl');
 
                 $(window).on('popstate.__back__', { self: this }, function (event) {
-                    var _this = event.data.self;
-                    var $refreshTarget = $('#col2');
-                    var refreshUrl;
+                    const _this = event.data.self;
+                    let $refreshTarget = $('#col2');
+                    let refreshUrl;
 
-                    var hash = icinga.history.getCol2State();
+                    const hash = icinga.history.getCol2State();
                     if (hash && hash.match(/^#!/)) {
                         // TODO: These three lines are copied from history.js, I don't like this
                         var parts = hash.split(/#!/);
@@ -524,22 +551,10 @@
                         $refreshTarget = $('#col1');
                     }
 
-                    // loadUrl won't run this request, as due to the history handling it's already running.
-                    // The important bit though is that it returns this (already running) request. This way
-                    // it's possible to set `scripted = true` on the request. (`addToHistory = true` should
-                    // already be the case, though it's added again just in case it's not already `true`..)
-                    var req = _this.loadUrl(refreshUrl, $refreshTarget);
-                    req.addToHistory = false;
-                    req.scripted = true;
-
-                    setTimeout(function () {
-                        // TODO: Find a better solution than a hardcoded one
-                        // This is still the *cheat* to get live results
-                        // (in case there's a delay and a change is not instantly effective)
-                        var req = _this.loadUrl(refreshUrl, $refreshTarget);
-                        req.addToHistory = false;
-                        req.scripted = true;
-                    }, 1000);
+                    const refreshReq = _this.loadUrl(refreshUrl, $refreshTarget);
+                    refreshReq.autoRefreshInterval = req.getResponseHeader('X-Icinga-Refresh');
+                    refreshReq.autorefresh = true;
+                    refreshReq.scripted = true;
 
                     $(window).off('popstate.__back__');
                 });
@@ -549,34 +564,41 @@
 
                 return true;
             } else if (redirect.match(/__CLOSE__/)) {
-                if (req.$redirectTarget.is('#col1')) {
+                if (req.$target.is('#col1') && req.$redirectTarget.is('#col1')) {
                     icinga.logger.warn('Cannot close #col1');
                     return false;
                 }
 
+                if (req.$redirectTarget.is('.container') && ! req.$redirectTarget.is('#main > :scope')) {
+                    // If it is a container that is not a top level container, we just empty it
+                    req.$redirectTarget.empty();
+                    return true;
+                }
+
+                if (! req.$redirectTarget.is('#col2')) {
+                    icinga.logger.debug('Cannot close container', req.$redirectTarget);
+                    return false;
+                }
+
                 // Close right column as requested
                 icinga.ui.layout1col();
 
-                // Refresh left column and produce a new history state for it
-                var $col1 = $('#col1');
-                var col1Url = icinga.history.getCol1State();
-                var refresh = this.loadUrl(col1Url, $col1);
-                refresh.scripted = true;
+                if (!! req.getResponseHeader('X-Icinga-Extra-Updates')) {
+                    icinga.logger.debug('Not refreshing #col1 due to outstanding extra updates');
+                    return true;
+                }
 
-                var _this = this;
-                setTimeout(function () {
-                    // TODO: Find a better solution than a hardcoded one
-                    // This is still the *cheat* to get live results
-                    // (in case there's a delay and a change is not instantly effective)
-                    var secondRefresh = _this.loadUrl(col1Url, $col1);
-                    if (secondRefresh !== refresh) {
-                        // Only change these properties if it's not still the first refresh
-                        secondRefresh.addToHistory = false;
-                        secondRefresh.scripted = true;
-                    }
-                }, 1000);
-
-                return true;
+                $redirectTarget = $('#col1');
+                redirect = icinga.history.getCol1State();
+            } else if (redirect.match(/__REFRESH__/)) {
+                if (req.$redirectTarget.is('#col1')) {
+                    redirect = icinga.history.getCol1State();
+                } else if (req.$redirectTarget.is('#col2')) {
+                    redirect = icinga.history.getCol2State().replace(/^#!/, '');
+                } else {
+                    icinga.logger.error('Unable to refresh. Not a primary column: ', req.$redirectTarget);
+                    return false;
+                }
             }
 
             var useHttp = req.getResponseHeader('X-Icinga-Redirect-Http');
@@ -585,7 +607,7 @@
                 return true;
             }
 
-            this.redirectToUrl(redirect, req.$redirectTarget, req);
+            this.redirectToUrl(redirect, $redirectTarget, req);
             return true;
         },
 
@@ -620,6 +642,7 @@
                 var redirectionUrl = icinga.utils.addUrlFlag(url, 'renderLayout');
                 var r = this.loadUrl(redirectionUrl, $('#layout'));
                 r.historyUrl = url;
+                r.referrer = referrer;
                 if (parts.length) {
                     r.loadNext = parts;
                 } else if (!! document.location.hash) {
@@ -644,16 +667,6 @@
                     this.loadUrl(parts.shift(), $('#col1'));
                     this.loadUrl(parts.shift(), $('#col2'));
                 } else {
-                    if ($target.attr('id') === 'col2') { // TODO: multicol
-                        if (($target.data('icingaUrl') || '').split('?')[0] === url.split('?')[0]) {
-                            // Don't do anything in this case
-                        } else if ($('#col1').data('icingaUrl').split('?')[0] === url.split('?')[0]) {
-                            icinga.ui.layout1col();
-                            $target = $('#col1');
-                            delete(this.requests['col2']);
-                        }
-                    }
-
                     var req = this.loadUrl(url, $target);
                     req.forceFocus = url === origin ? forceFocus : null;
                     req.autoRefreshInterval = autoRefreshInterval;
@@ -677,6 +690,7 @@
             var target = req.getResponseHeader('X-Icinga-Container');
             var newBody = false;
             var oldNotifications = false;
+            var isRedirect = !! req.getResponseHeader('X-Icinga-Redirect');
             if (target) {
                 if (target === 'ignore') {
                     return;
@@ -684,17 +698,26 @@
 
                 var $newTarget = this.identifyLinkTarget(target, req.$target);
                 if ($newTarget.length) {
-                    // If we change the target, oncomplete will fail to clean up
-                    // This fixes the problem, not using req.$target would be better
-                    delete this.requests[req.$target.attr('id')];
+                    if (isRedirect) {
+                        req.$redirectTarget = $newTarget;
+                    } else {
+                        // If we change the target, oncomplete will fail to clean up.
+                        // This fixes the problem, not using req.$target would be better
+                        delete this.requests[req.$target.attr('id')];
 
-                    req.$target = $newTarget;
-                    req.$redirectTarget = $newTarget;
+                        req.$target = $newTarget;
+                    }
 
                     if (target === 'layout') {
                         oldNotifications = $('#notifications li').detach();
                         this.icinga.ui.layout1col();
                         newBody = true;
+                    } else if ($newTarget.attr('id') === 'col2') {
+                        if (_this.icinga.ui.isOneColLayout()) {
+                            _this.icinga.ui.layout2col();
+                        } else if (target === '_next') {
+                            _this.icinga.ui.moveToLeft();
+                        }
                     }
                 }
             }
@@ -713,7 +736,7 @@
                 this.icinga.ui.reloadCss();
             }
 
-            if (req.getResponseHeader('X-Icinga-Redirect')) {
+            if (isRedirect) {
                 return;
             }
 
@@ -772,14 +795,9 @@
                 this.icinga.ui.setWindowId(windowId);
             }
 
-            var referrer = req.referrer;
-            if (typeof referrer === 'undefined') {
-                referrer = req;
-            }
-
             var autoSubmit = false;
             var currentUrl = this.icinga.utils.parseUrl(req.$target.data('icingaUrl'));
-            if (referrer.method === 'POST') {
+            if (req.method === 'POST') {
                 var newUrl = this.icinga.utils.parseUrl(req.url);
                 if (newUrl.path === currentUrl.path && this.icinga.utils.arraysEqual(newUrl.params, currentUrl.params)) {
                     autoSubmit = true;
@@ -799,7 +817,7 @@
                     let url = currentUrl.path + (locationQuery ? '?' + locationQuery : '');
                     if (req.autosubmit || autoSubmit) {
                         // Also update a form's action if it doesn't differ from the container's url
-                        var $form = $(referrer.forceFocus).closest('form');
+                        var $form = $(req.forceFocus).closest('form');
                         var formAction = $form.attr('action');
                         if (!! formAction) {
                             formAction = this.icinga.utils.parseUrl(formAction);
@@ -888,21 +906,76 @@
                 req = reqOrError;
             }
 
+            if (req.getResponseHeader('X-Icinga-Reload-Window') === 'yes') {
+                window.location.reload();
+                return;
+            }
+
+            req.$target.data('lastUpdate', (new Date()).getTime());
+            delete this.requests[req.$target.attr('id')];
+            this.icinga.ui.fadeNotificationsAway();
+
+            var extraUpdates = req.getResponseHeader('X-Icinga-Extra-Updates');
+            if (!! extraUpdates && req.getResponseHeader('X-Icinga-Redirect-Http') !== 'yes') {
+                $.each(extraUpdates.split(','), function (idx, el) {
+                    var parts = el.trim().split(';');
+                    var $target;
+                    var url;
+                    if (parts.length === 2) {
+                        $target = $(parts[0].startsWith('#') ? parts[0] : '#' + parts[0]);
+                        if (! $target.length) {
+                            _this.icinga.logger.warn('Invalid target ID. Cannot load extra URL', el);
+                            return;
+                        }
+
+                        url = parts[1];
+                    } else if (parts.length === 1) {
+                        $target = $(parts[0]).closest(".container").not(req.$target);
+                        if (! $target.length) {
+                            _this.icinga.logger.warn('Invalid target ID. Cannot load extra URL', el);
+                            return;
+                        }
+
+                        url = $target.data('icingaUrl');
+                        if (! url) {
+                            _this.icinga.logger.debug(
+                                'Superfluous extra update. The target\'s container has no url', el);
+                            return;
+                        }
+                    } else {
+                        _this.icinga.logger.error('Invalid extra update', el);
+                        return;
+                    }
+
+                    if (url === '__CLOSE__') {
+                        if ($target.is('#col2')) {
+                            _this.icinga.ui.layout1col();
+                        } else if ($target.is('#main > :scope')) {
+                            _this.icinga.logger.warn('Invalid target ID. Cannot close ', $target);
+                        } else if ($target.is('.container')) {
+                            // If it is a container that is not a top level container, we just empty it
+                            $target.empty();
+                        }
+                    } else {
+                        _this.loadUrl(url, $target).addToHistory = false;
+                    }
+                });
+            }
+
+            if ((textStatus === 'abort' && typeof req.referrer !== 'undefined') || this.processRedirectHeader(req)) {
+                return;
+            }
+
             // Remove 'impact' class if there was such
             if (req.$target.hasClass('impact')) {
                 req.$target.removeClass('impact');
             } else {
-                var $impact = req.$target.find('.impact').first();
+                const $impact = req.$target.find(':scope > .content.impact').first();
                 if ($impact.length) {
                     $impact.removeClass('impact');
                 }
             }
 
-            if (req.getResponseHeader('X-Icinga-Reload-Window') === 'yes') {
-                window.location.reload();
-                return;
-            }
-
             if (! req.autorefresh && ! req.autosubmit) {
                 // TODO: Hook for response/url?
                 var url = req.url;
@@ -940,45 +1013,6 @@
                 }
             }
 
-            req.$target.data('lastUpdate', (new Date()).getTime());
-            delete this.requests[req.$target.attr('id')];
-            this.icinga.ui.fadeNotificationsAway();
-
-            var extraUpdates = req.getResponseHeader('X-Icinga-Extra-Updates');
-            if (!! extraUpdates && req.getResponseHeader('X-Icinga-Redirect-Http') !== 'yes') {
-                $.each(extraUpdates.split(','), function (idx, el) {
-                    var parts = el.trim().split(';');
-                    var $target;
-                    var url;
-                    if (parts.length === 2) {
-                        $target = $('#' + parts[0]);
-                        if (! $target.length) {
-                            _this.icinga.logger.warn('Invalid target ID. Cannot load extra URL', el);
-                            return;
-                        }
-
-                        url = parts[1];
-                    } else if (parts.length === 1) {
-                        $target = $(parts[0]).closest(".container").not(req.$target);
-                        if (! $target.length) {
-                            _this.icinga.logger.warn('Invalid target ID. Cannot load extra URL', el);
-                            return;
-                        }
-
-                        url = $target.data('icingaUrl');
-                    } else {
-                        _this.icinga.logger.error('Invalid extra update', el);
-                        return;
-                    }
-
-                    _this.loadUrl(url, $target).addToHistory = false;
-                });
-            }
-
-            if (this.processRedirectHeader(req)) {
-                return;
-            }
-
             if (typeof req.loadNext !== 'undefined' && req.loadNext.length) {
                 if ($('#col2').length) {
                     var r = this.loadUrl(req.loadNext[0], $('#col2'));
@@ -1012,7 +1046,6 @@
             if (req.addToHistory && ! req.autorefresh) {
                 req.$target.data('icingaRefresh', 0);
                 req.$target.data('icingaUrl', url);
-                icinga.history.pushCurrentState();
             }
 
             if (typeof req.progressTimer !== 'undefined') {
@@ -1041,8 +1074,9 @@
                         req.$target
                     );
 
-                    // Aborted requests should not be added to browser history
-                    req.addToHistory = false;
+                    if (req.scripted) {
+                        req.addToHistory = false;
+                    }
                 } else {
                     if (this.failureNotice === null) {
                         var now = new Date();
@@ -1217,29 +1251,37 @@
                 if (autorefresh || autoSubmit) {
                     if ($container.css('display') === 'flex' && $container.is('.container')) {
                         var $scrollableContent = $container.children('.content');
-                        scrollPos = $scrollableContent.scrollTop();
+                        scrollPos = {
+                            x: $scrollableContent.scrollTop(),
+                            y: $scrollableContent.scrollLeft()
+                        };
                         scrollTarget = _this.icinga.utils.getCSSPath($scrollableContent);
                     } else {
-                        scrollPos = $container.scrollTop();
+                        scrollPos = {
+                            x: $container.scrollTop(),
+                            y: $container.scrollLeft()
+                        };
                     }
                 } else {
-                    scrollPos = 0;
+                    scrollPos = {
+                        x: 0,
+                        y: 0
+                    }
                 }
             }
 
             $container.trigger('beforerender', [content, action, autorefresh, scripted, autoSubmit]);
 
-            var discard = false;
-            $.each(_this.icinga.behaviors, function(name, behavior) {
-                if (behavior.renderHook) {
-                    var changed = behavior.renderHook(content, $container, action, autorefresh, autoSubmit);
-                    if (changed === null) {
-                        discard = true;
-                    } else {
-                        content = changed;
-                    }
+            let discard = false;
+            for (const hook of _this.icinga.renderHooks) {
+                const changed = hook.renderHook(content, $container, action, autorefresh, autoSubmit);
+                if (changed === null) {
+                    discard = true;
+                    break;
+                } else {
+                    content = changed;
                 }
-            });
+            }
 
             $('.container', $container).each(function() {
                 _this.stopPendingRequestsFor($(this));
@@ -1297,14 +1339,16 @@
 
             if (scrollPos !== false) {
                 var $scrollTarget = $(scrollTarget);
-                $scrollTarget.scrollTop(scrollPos);
 
                 // Fallback for browsers without support for focus({preventScroll: true})
-                setTimeout(function () {
-                    if ($scrollTarget.scrollTop() !== scrollPos) {
-                        $scrollTarget.scrollTop(scrollPos);
+                requestAnimationFrame(() => {
+                    if ($scrollTarget.scrollTop() !== scrollPos.x) {
+                        $scrollTarget.scrollTop(scrollPos.x);
                     }
-                }, 0);
+                    if ($scrollTarget.scrollLeft() !== scrollPos.y) {
+                        $scrollTarget.scrollLeft(scrollPos.y);
+                    }
+                });
             }
 
             // Re-enable all click events (disabled as of performance reasons)
